<template>
  <div class="all">
    <div class="kb-content">
      <div class="kb-center" ref="left">
        <div
          class="menu-item"
          v-for="(item, i) in tabList"
          :class="activePage == i ? 'menu-item-active' : ''"
          :key="i"
          @click="openRight( i)"
          ref="leftbar"
        >
          <img :src="item.icon_black" alt="" v-if="activePage != i" class="secondIcon">
          <img :src="item.icon_white" alt="" v-else class="secondIcon">
          <span class="title">{{ item.name }}</span>
        </div>
      </div>
      <div class="language-right">
        <div class="lang" v-if="activePage == 0">
          <div class="bar title">语言列表</div>
          <div
            class="bar"
            v-for="(item, i) in langList"
            :key="i"
            @click="pickLang(item, i)"
          >
            <span class="name">{{ item.Name }}</span>
            <span
              class="icon iconfont"
              style="color: var(--colorCard);font-size:16px;"
              v-show="activeLang == item.Lang"
              >&#xe759;</span
            >
          </div>
        </div>
        <div class="lang" v-if="activePage == 1">
          <div class="title bar">键盘布局</div>
          <div
            class="bar"
            v-for="(item, i) in keyboardList"
            :key="i"
            @click="pickKb(item, i)"
          >
            <span class="name">{{ item.name }}</span>
            <span
              class="icon iconfont"
              style="color: #4E94FF;font-size:16px;"
              v-show="activeKb == item.id"
              >&#xe759;</span
            >
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import {
  getLangs,
  setLang,
  getLang,
  getKeyboardLayouts,
  getCurKeyboardLayout,
  setKeyboardLayout,
} from "@/api/system";

export default {
  data() {
    return {
      activeLang: "",
      activeKb: "",
      langList: [],
      keyboardList: [],
      tabList: [
        { name: "系统语言", icon: "\ue74a" ,icon_white:"/images/settings/语言-白.png",icon_black:"/images/settings/语言-黑.png"},
        { name: "键盘管理", icon: "\ue74e" ,icon_white:"/images/settings/键盘-白.png",icon_black:"/images/settings/键盘-黑.png"},
      ],
      activePage: 0,
    };
  },
  mounted() {
    this.fetchLangList();
    this.getCurLang();
    this.fetchKeyBoardList();
    this.getCurKb();
  },
  methods: {
    getCurKb() {
      getCurKeyboardLayout().then((res) => {
        this.activeKb = res.data.keyboard;
      });
    },
    getCurLang() {
      getLang().then((res) => {
        if (res && res.success) {
          this.activeLang = res.data.lang;
        }
      });
    },
    fetchLangList() {
      getLangs().then((res) => {
        if (res && res.success) {
          this.langList = res.data;
        }
      });
    },
    fetchKeyBoardList() {
      getKeyboardLayouts().then((res) => {
        if (res && res.success) {
          this.keyboardList = res.data.slice(0, 5);
        }
      });
    },
    pickLang(item) {
      if (item.Lang==this.activeLang) {
        return
      }
      setLang({
        lang: item.Lang,
      }).then(
        (res) => {
          this.getCurLang();
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    pickKb(item) {
      if (this.activeKb==item.id) {
        return
      }
      setKeyboardLayout({
        layout: item.id,
      }).then(
        (res) => {
          this.getCurKb();
          this.$message.success(res.data);
        },
        (err) => {
          this.$message.error(err.msg);
        }
      );
    },
    openRight(i) {
      this.activePage = i;
    },
  },
};
</script>
<style lang="scss">
.all {
  width: 100%;
}

.kb-content {
  font-weight: 700;
  height: 100%;
  display: flex;
  flex-direction: row;
  flex: 1;
  flex-basis: auto;
  box-sizing: border-box;
  .kb-center {
    height: 100%;
    width: 300px;
    overflow: auto;
    box-sizing: border-box;
    flex-shrink: 0;
    padding: 6px 10px 0px 10px;
    background-color: #FBFAFF;
    border-right: 4px solid #F2F2F7;
    border-top: 4px solid #F2F2F7;
    border-left: 4px solid #F2F2F7;
    .menu-item {
    /*   background-color: #F2F2F7; */
      height: 56px;
      margin-bottom: 4px;
      border-radius: 8px;
      line-height: 56px;
      box-sizing: border-box;
      padding: 0 20px;cursor: pointer;
      display: flex;
      align-items: center;
      color: #4F4F4F;
      .title {
        font-size: 16px;
        font-weight: 700;
      }
      .secondIcon {
        margin: 15px;
        width: 24px;
        height: 24px;
      }
    }
    .menu-item-active {
      background-color: var(--colorCard) !important;
      color: white;
      
    }
    .menu-item:hover {
      background-color: #F2F2F7;
    }
  }
  .language-right {
    flex: 1;
    flex-basis: auto;
    overflow: auto;
    box-sizing: border-box;
    position: relative;
    padding: 10px;
    padding-top: 6px;
    border-top: 4px solid #F2F2F7;
    .el-form-item.is-required:not(.is-no-asterisk)
      > .el-form-item__label:before,
    .el-form-item.is-required:not(.is-no-asterisk)
      .el-form-item__label-wrap
      > .el-form-item__label:before {
      display: none;
    }
    .el-select {
      width: 100%;
    }
    .el-form-item {
      margin-bottom: 10px;
      height: 50px;
      background: #f8f8f8;
      padding: 4px 20px;
      -webkit-box-sizing: border-box;
      box-sizing: border-box;
      border-radius: 10px;
      .el-form-item__label {
        text-align: left;
        line-height: 42px;
      }
    }
    .el-form-item__content {
      line-height: 40px;
      position: relative;
      font-size: 14px;
    }
    .ip-input-container {
      max-width: none !important;
    }
    .lang {
      .bar {
        height: 48px;
        background-color: #f8f8f8;
        border-radius: 8px;
        line-height: 50px;
        box-sizing: content-box;
        padding: 0 15px 0 20px;
        display: flex;
        justify-content: space-between;
        cursor: pointer;
        margin-bottom: 4px;
        border: 2px solid #f8f8f8;
        .name{
               font-size: 14px;
        }
      }
      .bar:hover{
            border: 2px solid var(--colorCard);
      }
      .title {
         cursor:default ;
        font-size: 16px;
       justify-content: center;
       border: 2px solid #f8f8f8 !important;
      }
    }
    /* .save-btn {
      background-color: #3d68e1;
      width: 240px;
      height: 40px;
      margin: 0 auto;
      border-radius: 10px;
      color: #fff;
      line-height: 40px;
      font-size: 14px;
      margin-top: 20px;
    } */
  }
}
</style>
